# orbit-etl
Repository for a Python package to extract data from MySQL and load it into GCS. This removes the duplication of code in many of the Airflow DAGs defined in [airflow-orchestration](https://github.com/orbitremit/airflow-orchestration)